import React, { useState, useEffect } from 'react';

const BasicDetails = ({ onDataUpdate, initialData, userName, userRole }) => {
  const [formData, setFormData] = useState(initialData || {
    intent: 'Sell',
    propertyType: '',
    sizeUnit: 'SQ Yard',
    size: '',
    length: '',
    breadth: ''
  });
  const [showFlash, setShowFlash] = useState(false);

  const handleLeaseClick = () => {
    setShowFlash(true);
    setTimeout(() => setShowFlash(false), 3000);
    setFormData(prev => ({ ...prev, intent: 'Lease' }));
  };

  useEffect(() => {
    onDataUpdate(formData);
  }, [formData, onDataUpdate]);

  const handleInputChange = (field, value) => {
    const updatedData = {
      ...formData,
      [field]: value
    };
    setFormData(updatedData);
  };

  const propertyTypes = [
    { value: 'residential', label: 'Residential land' },
    { value: 'commercial', label: 'Commercial land' },
    { value: 'agricultural', label: 'Agricultural land' }
  ];

  const sizeUnits = [
    { value: 'SQ Yard', label: 'SQ Yard' },
    { value: 'SQ Feet', label: 'SQ Feet' },
    { value: 'SQ Meter', label: 'SQ Meter' }
  ];

  return (
    <div className="w-full max-w-2xl mx-auto">
      {showFlash && (
        <div className="fixed top-4 left-1/2 transform -translate-x-1/2 z-50 animate-fade-in-down">
          <div className="bg-yellow-100 border-l-4 border-yellow-500 text-yellow-700 p-4 rounded shadow-lg">
            <p className="text-sm sm:text-base">
              This section is under construction
            </p>
          </div>
        </div>
      )}

      <div className="flex flex-col gap-6 sm:gap-8">
        {/* Header with User Info */}
        <h2 className="text-2xl sm:text-3xl font-semibold mb-4">
          Hello! {userName}{" "}
          <span className="inline-block bg-red-300 text-gray-700 text-sm font-medium px-1 py-1 rounded">
            {userRole && <span>Role: {userRole}</span>}
          </span>
        </h2>

        {/* Intent Selection */}
        <div className="flex flex-wrap justify-start items-start gap-8">
          <div className="flex flex-col">
            <p className="mb-4 text-base sm:text-lg">Post property for?</p>
            <div className="flex flex-wrap gap-4">
              <button
                type="button"
                onClick={() => handleInputChange('intent', 'Sell')}
                className={`rounded-full px-4 py-2 sm:px-6 transition-colors duration-200 ${
                  formData.intent === 'Sell'
                    ? 'bg-purple-600 text-white'
                    : 'border border-gray-300 text-gray-700 hover:bg-gray-50'
                }`}
              >
                Sell
              </button>
              <button
                type="button"
                onClick={handleLeaseClick}
                className={`rounded-full px-4 py-2 sm:px-6 transition-colors duration-200 ${
                  formData.intent === 'Lease'
                    ? 'bg-purple-600 text-white'
                    : 'border border-gray-300 text-gray-700 hover:bg-gray-50'
                }`}
              >
                Lease
              </button>
            </div>
          </div>
        </div>

        {/* Property Type and Size */}
        <div>
          <h3 className="mb-3 text-base font-medium sm:mb-4 sm:text-lg">
            Type of Property & Size?
          </h3>
          <div className="grid gap-3 sm:gap-4 md:grid-cols-3">
            <div>
              <select
                className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
                value={formData.propertyType}
                onChange={(e) => handleInputChange('propertyType', e.target.value)}
              >
                <option value="">Select Property Type</option>
                {propertyTypes.map(type => (
                  <option key={type.value} value={type.value}>
                    {type.label}
                  </option>
                ))}
              </select>
            </div>

            <div>
              <input
                type="text"
                placeholder="Size"
                value={formData.size}
                onChange={(e) => handleInputChange('size', e.target.value)}
                className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
              />
            </div>

            <select
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
              value={formData.sizeUnit}
              onChange={(e) => handleInputChange('sizeUnit', e.target.value)}
            >
              {sizeUnits.map(unit => (
                <option key={unit.value} value={unit.value}>
                  {unit.label}
                </option>
              ))}
            </select>
          </div>
        </div>

        {/* Property Dimensions */}
        <div>
          <h3 className="mb-3 text-base font-medium sm:mb-4 sm:text-lg">
            Property Dimension
          </h3>
          <div className="grid gap-3 sm:gap-4 md:grid-cols-2">
            <div>
              <label htmlFor="length" className="block text-sm mb-1">Length</label>
              <input
                id="length"
                type="number"
                placeholder="Length"
                value={formData.length}
                onChange={(e) => handleInputChange('length', e.target.value)}
                className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
              />
            </div>
            <div>
              <label htmlFor="breadth" className="block text-sm mb-1">Breadth</label>
              <input
                id="breadth"
                type="number"
                placeholder="Breadth"
                value={formData.breadth}
                onChange={(e) => handleInputChange('breadth', e.target.value)}
                className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
              />
            </div>
          </div>
        </div>
      </div>

      <style jsx>{`
        @keyframes fadeInDown {
          from {
            opacity: 0;
            transform: translate(-50%, -100%);
          }
          to {
            opacity: 1;
            transform: translate(-50%, 0);
          }
        }
        .animate-fade-in-down {
          animation: fadeInDown 0.5s ease-out;
        }
      `}</style>
    </div>
  );
};

export default BasicDetails;